# sparc-curation
[![PyPI version](https://badge.fury.io/py/sparcur.svg)](https://pypi.org/project/sparcur/)
[![Build Status](https://travis-ci.org/SciCrunch/sparc-curation.svg?branch=master)](https://travis-ci.org/SciCrunch/sparc-curation)
[![Coverage Status](https://coveralls.io/repos/github/SciCrunch/sparc-curation/badge.svg?branch=master)](https://coveralls.io/github/SciCrunch/sparc-curation?branch=master)

code, files, and documentation for SPARC curation workflows

## Setup
New developers or curators should start by following [setup.org](./docs/setup.org).

## Background
For a general introduction to the SPARC curpation process see [background.org](./docs/background.org).

## Workflows
Documentation for curation workflows currently lives in [setup.org](./docs/setup.org#workflows).

## Developer guide
See the [developer guide](./docs/developer-guide.org) for examples of how to reuse and develop sparcur.
